#include <stdio.h>
#include <stdlib.h>
#include <SDL2/SDL.h>

void sdlperror(const char* header){
	const char* error = SDL_GetError();
	printf("%s: %s\n",header,error);
	exit(1);
}

extern C_LINKAGE int main(int argc, char *argv[]) {
	if (SDL_Init(SDL_INIT_VIDEO) == -1) {
		sdlperror("SDL_Init");
		return 1;
	}
	int result;
	SDL_Window* window;
	SDL_Renderer* renderer;
	result = SDL_CreateWindowAndRenderer(640,480,0,&window,&renderer);
	if (result != 0) {
		sdlperror("SDL_CreateWindowAndRenderer");
	}
	SDL_Event event;
	int end = 0;

	while (!end) {
		if (SDL_WaitEvent(&event) == 0) {
			sdlperror("SDL_WaitEvent");
			return 1;
		}
		switch (event.type) {
			case SDL_MOUSEBUTTONDOWN:
			case SDL_MOUSEBUTTONUP:
				printf("mouse button = %d, state = %d\n", event.button.button, event.button.state);
			break;

			case SDL_MOUSEMOTION:
				printf("mouse motion, state = %d, x = %d, y = %d\n", event.motion.state, event.motion.x, event.motion.y);
			break;

			case SDL_WINDOWEVENT:
				printf("window event = %d\n", event.window.event);
			break;

			case SDL_QUIT:
				end = 1;
			break;
			
			default:
				printf("event type = 0x%X\n", event.type);
			break;
		}
	}

	SDL_Quit();
	return 0;
}

